@@ -44,7 +44,7 @@ __author__ = 'Álan Crístoffer'
 __copyright__ = 'Copyright 2016, Álan Crístoffer'
 __credits__ = ['Álan Crístoffer']
 __license__ = 'MIT'
-__version__ = '1.0.5'
+__version__ = '1.0.10'
 __maintainer__ = 'Álan Crístoffer'
 __email__ = 'acristoffers@gmail.com'
 __status__ = 'Release'
@@ -59,6 +59,16 @@ def add_path(path):
     drivers.add_path(path)
 
 
+def remove_path(path):
+    """Removes a directory from the list of folders where to load drivers from"""
+    drivers.remove_path(path)
+
+
+def clear_path():
+    """Clears the list of folders where to load drivers from"""
+    drivers.clear_path()
+
+
 def list_available_drivers():
     """Returns a list of string with the names of available drivers.
 
